@@ -1,5 +1,4 @@
 import csv
-from datetime import datetime, timezone
 import logging
 import re
 import xml.etree.ElementTree as et
@@ -9,12 +8,19 @@ from dateutil import parser, tz
 from geopy import distance
 import voluptuous as vol
 
+from . import ec_exc
+
 SITE_LIST_URL = "https://dd.weather.gc.ca/citypage_weather/docs/site_list_en.csv"
 
-WEATHER_URL = "https://hpfx.collab.science.gc.ca/{date}/WXO-DD/citypage_weather/xml/{site}_{language}.xml"
+WEATHER_URL = "https://dd.weather.gc.ca/citypage_weather/xml/{}_{}.xml"
 
 LOG = logging.getLogger(__name__)
 
+ATTRIBUTION = {
+    "english": "Data provided by Environment Canada",
+    "french": "Données fournies par Environnement Canada",
+}
+
 conditions_meta = {
     "temperature": {
         "xpath": "./currentConditions/temperature",
@@ -131,6 +137,18 @@ conditions_meta = {
         "english": "Precipitation Yesterday",
         "french": "Précipitation d'hier",
     },
+    "normal_high": {
+        "xpath": './forecastGroup/regionalNormals/temperature[@class="high"]',
+        "type": "int",
+        "english": "Normal High Temperature",
+        "french": "Haute température normale",
+    },
+    "normal_low": {
+        "xpath": './forecastGroup/regionalNormals/temperature[@class="low"]',
+        "type": "int",
+        "english": "Normal Low Temperature",
+        "french": "Basse température normale",
+    },
 }
 
 summary_meta = {
@@ -208,9 +226,8 @@ async def get_ec_sites():
     return sites
 
 
-async def closest_site(lat, lon):
+def closest_site(site_list, lat, lon):
     """Return the province/site_code of the closest station to our lat/lon."""
-    site_list = await get_ec_sites()
 
     def site_distance(site):
         """Calculate distance to a site."""
@@ -253,7 +270,7 @@ class ECWeather(object):
         kwargs = init_schema(kwargs)
 
         self.language = kwargs["language"]
-        self.metadata = {}
+        self.metadata = {"attribution": ATTRIBUTION[self.language]}
         self.conditions = {}
         self.alerts = {}
         self.daily_forecasts = []
@@ -262,28 +279,38 @@ class ECWeather(object):
 
         if "station_id" in kwargs and kwargs["station_id"] is not None:
             self.station_id = kwargs["station_id"]
+            self.lat = None
+            self.lon = None
         else:
             self.station_id = None
-            self.coordinates = kwargs["coordinates"]
+            self.lat = kwargs["coordinates"][0]
+            self.lon = kwargs["coordinates"][1]
 
     async def update(self):
         """Get the latest data from Environment Canada."""
 
-        # Determine station ID if not provided
-
-        if not self.station_id and self.coordinates:
-            self.station_id = await closest_site(*self.coordinates)
+        # Determine station ID or coordinates if not provided
+        site_list = await get_ec_sites()
+        if self.station_id:
+            stn = self.station_id.split("/")
+            if len(stn) == 2:
+                for site in site_list:
+                    if stn[1] == site["Codes"] and stn[0] == site["Province Codes"]:
+                        self.lat = site["Latitude"]
+                        self.lon = site["Longitude"]
+                        break
+            if not self.lat:
+                raise ec_exc.UnknownStationId
+        else:
+            self.station_id = closest_site(site_list, self.lat, self.lon)
+            if not self.station_id:
+                raise ec_exc.UnknownStationId
 
         # Get weather data
 
         async with ClientSession(raise_for_status=True) as session:
             response = await session.get(
-                WEATHER_URL.format(
-                    date=datetime.now(tz=timezone.utc).strftime("%Y%m%d"),
-                    site=self.station_id,
-                    language=self.language[0],
-                ),
-                timeout=10,
+                WEATHER_URL.format(self.station_id, self.language[0]), timeout=10
             )
             result = await response.read()
         weather_xml = result.decode("iso-8859-1")
